@@ -31,7 +31,7 @@ class HRESDownloader(ClimateDownloader):
     # https://confluence.ecmwf.int/pages/viewpage.action?pageId=85402030
     # https://confluence.ecmwf.int/display/CKB/ERA5%3A+data+documentation#ERA5:datadocumentation-Dateandtimespecification
     HRES_PARAMS = {
-        "siconca":      (31, "siconc"), # sea_ice_area_fraction
+        "siconca":      (31, "siconc"),  # sea_ice_area_fraction
         "tos":          (34, "sst"),    # sea surface temperature (actually
                                         # sst?)
         "zg":           (129, "z"),     # geopotential
@@ -58,11 +58,11 @@ class HRESDownloader(ClimateDownloader):
         #       165.128 / 166.128 / 167.128 / 169.128 / 177.128
 
         # ORAS5 variables in param-db (need to consider depth)
-        #"thetao":       (151129, "thetao"),
-        #"so":           (151130, "so"),
+        # "thetao":       (151129, "thetao"),
+        # "so":           (151130, "so"),
         # Better matches than equivalent X / Y parameters in param-db
-        #"uo":           (151131, "uo"),
-        #"vo":           (151132, "vo"),
+        # "uo":           (151131, "uo"),
+        # "vo":           (151132, "vo"),
     }
 
     # https://confluence.ecmwf.int/display/UDOC/Keywords+in+MARS+and+Dissemination+requests
@@ -163,7 +163,7 @@ retrieve,
         logging.debug("Files downloaded: {}".format(downloads))
 
         ds = xr.open_mfdataset(downloads)
-        ds = ds.resample(time='1D').mean()
+        ds = ds.resample(time='1D', keep_attrs=True).mean(keep_attrs=True)
 
         for var_name, pressure in product(var_names, pressures.split('/')
                                           if pressures else [None]):
@@ -194,11 +194,11 @@ retrieve,
                      "from {} API".format(self.identifier.upper()))
 
         sfc_vars = [var for idx, var in enumerate(self.var_names)
-                    if not self.pressure_levels[idx]]
-        plev_vars = [var for idx, var in enumerate(self.var_names)
-                     if self.pressure_levels[idx]]
-        pressures = "/".join([str(s) for s in sorted(set(
-            [p for ps in self.pressure_levels if ps for p in ps]))])
+                    if not self.levels[idx]]
+        level_vars = [var for idx, var in enumerate(self.var_names)
+                      if self.levels[idx]]
+        levels = "/".join([str(s) for s in sorted(set(
+            [p for ps in self.levels if ps for p in ps]))])
 
         # req_dates = self.filter_dates_on_data()
 
@@ -210,8 +210,8 @@ retrieve,
             if len(sfc_vars) > 0:
                 self._single_download(sfc_vars, None, req_batch)
 
-            if len(plev_vars) > 0:
-                self._single_download(plev_vars, pressures, req_batch)
+            if len(level_vars) > 0:
+                self._single_download(level_vars, levels, req_batch)
 
         logging.info("{} daily files downloaded".
                      format(len(self._files_downloaded)))
@@ -409,17 +409,16 @@ def main(identifier, extra_kwargs=None):
     instance = cls(
         identifier="mars.{}".format(identifier.lower()),
         var_names=args.vars,
-        pressure_levels=args.levels,
         dates=[pd.to_datetime(date).date() for date in
                pd.date_range(args.start_date, args.end_date, freq="D")],
         delete_tempfiles=args.delete,
+        levels=args.levels,
         north=args.hemisphere == "north",
         south=args.hemisphere == "south",
         **extra_kwargs
     )
     instance.download()
     instance.regrid()
-    instance.rotate_wind_data()
 
 
 def seas_main():
